@@ -12,7 +12,6 @@ from itertools import zip_longest
 from pathlib import Path
 from shutil import copyfileobj
 from zlib import decompress
-from zlib import error as ZlibError
 
 from PIL import Image, ImageCms
 from PIL.TiffTags import TAGS_V2 as TIFF_TAGS
@@ -252,9 +251,7 @@ class PdfImageBase(ABC):
             _idx, base, _hival, lookup = self._colorspaces
         except ValueError as e:
             raise ValueError('Not sure how to interpret this palette') from e
-        iccobj = None
         if self.icc:
-            iccobj = base[1]
             base = str(base[0])
         else:
             base = str(base)
@@ -329,6 +326,8 @@ class PdfImage(PdfImageBase):
         self._icc = None
 
     def __eq__(self, other):
+        if not isinstance(other, PdfImageBase):
+            return NotImplemented
         return self.obj == other.obj
 
     @classmethod
@@ -717,6 +716,15 @@ class PdfJpxImage(PdfImage):
         super().__init__(obj)
         self._jpxpil = self.as_pil_image()
 
+    def __eq__(self, other):
+        if not isinstance(other, PdfImageBase):
+            return NotImplemented
+        return (
+            self.obj == other.obj
+            and isinstance(other, PdfJpxImage)
+            and self._jpxpil == other._jpxpil
+        )
+
     def _extract_direct(self, *, stream):
         data, filters = self._unstack_compression(
             self.obj.get_raw_stream_buffer(), self.filters
@@ -812,9 +820,15 @@ class PdfInlineImage(PdfImageBase):
         self.pil = None
 
     def __eq__(self, other):
-        return self.obj == other.obj and (
-            self._data._inline_image_raw_bytes()
-            == other._data._inline_image_raw_bytes()
+        if not isinstance(other, PdfImageBase):
+            return NotImplemented
+        return (
+            self.obj == other.obj
+            and isinstance(other, PdfInlineImage)
+            and (
+                self._data._inline_image_raw_bytes()
+                == other._data._inline_image_raw_bytes()
+            )
         )
 
     @classmethod
